#light_clock_simple.py
# Basic code for the light clock

# Import the required libraries
import RPi.GPIO as GPIO
import time
import datetime
import schedule

alarmTime = '23:21'
alarmOff = '08:40'

# GPIO setup
GPIO.setmode(GPIO.BCM)  # Use the BCM pinout
GPIO.setwarnings(False)
ledStripPin = 19        # LED strip is driven from this pin
# The hour LEDs are connected to these pins (in order from 1 to 12):
hourPin = [25, 24, 23, 18, 15, 14, 8, 20, 16, 12, 1, 7]

# Set all the hourPins as outputs
for clockHour in range(0, 12):
    GPIO.setup(hourPin[clockHour], GPIO.OUT)
    GPIO.output(hourPin[clockHour], 0)

GPIO.setup(ledStripPin, GPIO.OUT)   # Set ledStripPin as an output
pwm = GPIO.PWM(ledStripPin, 100)    # PWM on ledStripPin with frequency 100Hz
dutyCycle = 0                       # Initial brightness as percent
pwm.start(dutyCycle)

# Define functions
def light_on():
    for dutyCycle in range(0, 101, 1):
        pwm.ChangeDutyCycle(dutyCycle)
        time.sleep(0.03)

def light_off():
    for dc in range(95, 0, -1):
        pwm.ChangeDutyCycle(dc)
        time.sleep(0.05)

def display_time(lastHour):
    # Find the hour of day
    now = datetime.datetime.now()
    thisHour = now.hour

    # Convert to 12 hour clock if we're in the afternoon
    if thisHour > 11:
        thisHour = thisHour - 12

    # Update displayed time if needed
        if thisHour != lastHour:
        GPIO.output(hourPin[thisHour-2], 0) # Turn off the last LED
        GPIO.output(hourPin[thisHour-1], 1) # Turn on the new one

    lastHour = thisHour
    return lastHour

schedule.every().day.at(alarmTime).do(light_on)
schedule.every().day.at(alarmOff).do(light_off)


myTime = 0
try:
  while True:
    schedule.run_pending()          # Check for the alarm
    myTime = display_time(myTime)   # Check for the time displayed
    time.sleep(1)                   # Wait 1 second

except KeyboardInterrupt:           # If CTRL-C is pressed quit the program, but first:
    pwm.stop()                      # Stop the pwm
    GPIO.cleanup()                  # Good practice before closing down